"use client";

import { getPlayer } from "mcutils-library";
import { Player } from "mcutils-library/dist/types/player/player";
import Image from "next/image";
import Link from "next/link";
import { useState } from "react";
import { toast } from "react-toastify";
import { Button } from "./ui/button";
import { Card } from "./ui/card";
import { Input } from "./ui/input";

const defaultPlayerId = "Notch";

export default function PlayerSearch() {
  const [playerId, setPlayerId] = useState<string>(defaultPlayerId);
  const [player, setPlayer] = useState<Player | null>(null);

  const handleLookup = async () => {
    if (playerId === null || playerId.length <= 0) {
      toast.error("Please enter a player ID");
      return;
    }
    try {
      const cachedPlayer = await getPlayer(playerId);
      const { player } = cachedPlayer;

      setPlayer(player);
    } catch (error) {
      toast.error("Unknown player");
      return;
    }
  };

  const handleKeyDown = (e: any) => {
    if (e.key === "Enter") {
      handleLookup();
    }
  };

  return (
    <div className="flex flex-col items-center gap-8">
      <div className="flex items-center gap-2">
        <Input
          className="w-[200px]"
          placeholder="Player ID"
          defaultValue={defaultPlayerId}
          onChange={(e) => setPlayerId(e.target.value)}
          onKeyDown={handleKeyDown}
        />
        <Button onClick={() => handleLookup()}>Lookup</Button>
      </div>

      {player && (
        <Card>
          <div className="w-full flex flex-col md:flex-row gap-2">
            <div className="flex justify-center">
              <Image src={player.skin.parts.head} alt="The player's Head" width={150} height={150} />
            </div>
            <div className="flex flex-col gap-1 mt-2">
              <p>
                UUID: <span className="font-bold">{player.uniqueId}</span>
              </p>
              <p>
                Name: <span className="font-bold">{player.username}</span>
              </p>
              <div className="mt-2">
                <p>Skin Parts</p>
                <div className="flex gap-2">
                  {Object.keys(player.skin.parts).map((part: any, index: number) => {
                    return (
                      <p key={index}>
                        <Link className="text-primary" href={player.skin.parts[part]} target="_blank">
                          {part}
                        </Link>
                      </p>
                    );
                  })}
                </div>
              </div>
            </div>
          </div>
        </Card>
      )}
    </div>
  );
}
